@@ -1,6 +1,6 @@
-from .charts import Bar, Line
+from .charts import Bar, Line, Pie
 from .components import Title, Toolbox
 from .mapping import Mapping
 from . import seriesProps as props
 
-__version__ = "0.1.2"
+__version__ = "0.1.4"
